import { BlLifeRechargeServicesOptions } from './types';
import { LifeRechargeConstants } from './lifeRechargeConstants';
import { Request, IRequest } from 'senior-request';
import { BlLifeRecharge } from './lifeRecharge';

export interface RequestConfig {}

export class BlLifeRechargeServices<TResponse = any, TRequestOptions = any> {
  private request: IRequest;
  ctx: BlLifeRecharge<TResponse, TRequestOptions>;

  constructor(
    ctx: BlLifeRecharge<TResponse, TRequestOptions>,
    { axiosConfig }: BlLifeRechargeServicesOptions<TResponse, TRequestOptions>
  ) {
    this.ctx = ctx;
    this.request = Request.create({
      ...axiosConfig,
      // baseURL: process.env.NODE_ENV === 'development' ? '/' : 'https://api.81812333.com',
      requestInterceptors: [
        [
          (config) => {
            if (config.params) {
              config.params.checkChannelId = this.ctx.accountModel.channlesNum;
            }
            if (config.data) {
              config.data.checkChannelId = this.ctx.accountModel.channlesNum;
            }
            return config;
          },
        ],
        ...axiosConfig.requestInterceptors,
      ],
      timeout: 10 * 1000,
      headers: {
        Accept: 'application/json, text/plain, */*',
        'Content-Type': 'application/json',
        'X-Requested-With': 'XMLHttpRequest',
      },
      withCredentials: true,
    });
  }

  async lifePayPhoneMesssageCodeLogin(body: PhoneMesssageCodeLoginInput, options?: RequestConfig) {
    return this.request<LifePayPhoneMesssageCodeLoginOutput>(
      '/api/Account/LifePayPhoneMesssageCodeLogin',
      {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        data: body,
        ...(options || {}),
      }
    );
  }

  /** 获取折扣 GET /api/LifePay/GetRate */
  async getRate(options?: RequestConfig) {
    return this.request<LifePayRateListOutput[]>('/api/LifePay/GetRate', {
      method: 'GET',
      ...(options || {}),
    });
  }

  /** 获取电费充值区域 GET /api/LifePay/GetElectricSupportArea */
  async getElectricSupportArea(body: ChannelsBaseInput, options?: RequestConfig) {
    return this.request<ElectricSupportAreaResponse>('/api/LifePay/GetElectricSupportArea', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 获取电费面值 POST /api/LifePay/GetElectricParValue */
  async getElectricParValue(body: ChannelsBaseInput, options?: RequestConfig) {
    return this.request<ElectricParValueResponse>('/api/LifePay/GetElectricParValue', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 获取话费面值 GET /api/LifePay/GetPhoneParValue */
  async getPhoneParValue(body: ChannelsBaseInput, options?: RequestConfig) {
    return this.request<PhoneParValueResponse>('/api/LifePay/GetPhoneParValue', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 创建生活缴费话费订单 POST /api/LifePay/CreateLifePayPhoneOrder */
  async createLifePayPhoneOrder(
    body: LifePhoneDataCreateLifePayOrderInput,
    options?: RequestConfig
  ) {
    return this.request<CreateLifePayOrderOutput>('/api/LifePay/CreateLifePayPhoneOrder', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 创建生活缴费电费订单 POST /api/LifePay/CreateLifePayElectricOrder */
  async createLifePayElectricOrder(
    body: LifeElectricDataCreateLifePayOrderInput,
    options?: RequestConfig
  ) {
    return this.request<CreateLifePayOrderOutput>('/api/LifePay/CreateLifePayElectricOrder', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 根据订单号获取支付状态 GET /api/LifePay/GetPayStatusByOrderNo */
  async getPayStatusByOrderNo(body: GetPayStatusByOrderNoInput, options?: RequestConfig) {
    return this.request<LifeRechargeConstants.LifePayStatusEnum>(
      '/api/LifePay/GetPayStatusByOrderNo',
      {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        data: body,
        ...(options || {}),
      }
    );
  }

  async setLifePayOrderPayType(body: SetLifePayOrderPayTypeInput, options?: RequestConfig) {
    return this.request<string>('/api/LifePay/SetLifePayOrderPayType', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 获取我的订单分页数据 POST /api/LifePay/GetUserLifePayOrderPage */
  async getUserLifePayOrderPage(body: QueryLifePayOrderListInput, options?: RequestConfig) {
    return this.request<UserLifePayOrderOutputPageOutput>('/api/LifePay/GetUserLifePayOrderPage', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 获取生活缴费用户身份会话信息 GET /api/Account/GetLifePayWxIndentity */
  async getLifePayWxIndentity(
    // 叠加生成的Param类型 (非body参数swagger默认没有生成对象)
    params: APIgetLifePayWxIndentityParams,
    options?: RequestConfig
  ) {
    return this.request<WxMiniAppIndentityInfo>('/api/Account/GetLifePayWxIndentity', {
      method: 'GET',
      params: {
        ...params,
      },
      ...(options || {}),
    });
  }

  /** 获取微信支付的JSAPI POST /api/LifePay/GetPayOrderForJsAPI */
  async getPayOrderForJsAPI(body: GetPayOrderForJsAPIInput, options?: RequestConfig) {
    return this.request<ModelPaymentMiniPay>('/api/LifePay/GetPayOrderForJsAPI', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 获取我的全部户号列表 POST /api/LifePay/GetUserAccountAllList */
  async getUserAccountAllList(body: QueryUserAccountAllListInput, options?: RequestConfig) {
    return this.request<UserAccountListOutput[]>('/api/LifePay/GetUserAccountAllList', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 获取我的户号列表 POST /api/LifePay/GetUserAccountList */
  async getUserAccountList(body: QueryUserAccountListInput, options?: RequestConfig) {
    return this.request<UserAccountListOutputPageOutput>('/api/LifePay/GetUserAccountList', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 添加或修改我的户号 POST /api/LifePay/AddUpdateUserAccount */
  async addUpdateUserAccount(body: AddUpdateUserAccountInput, options?: RequestConfig) {
    return this.request<number>('/api/LifePay/AddUpdateUserAccount', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 创建生活缴费燃气订单 POST /api/LifePay/CreateLifePayGasOrder */
  async createLifePayGasOrder(body: LifeGasDataCreateLifePayOrderInput, options?: RequestConfig) {
    return this.request<CreateLifePayOrderOutput>('/api/LifePay/CreateLifePayGasOrder', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 获取燃气面值 GET /api/LifePay/GetGasParValue */
  async getGasParValue(body: ChannelsBaseInput, options?: RequestConfig) {
    return this.request<GasParValueResponse>('/api/LifePay/GetGasParValue', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 用户发起生活缴费退款 POST /api/LifePay/RefundUserLifePayOrder */
  async refundUserLifePayOrder(body: RefundUserLifePayOrderInput, options?: RequestConfig) {
    return this.request<number>('/api/LifePay/RefundUserLifePayOrder', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 删除我的户号 POST /api/LifePay/DeleteUserAccount */
  async deleteUserAccount(
    // 叠加生成的Param类型 (非body参数swagger默认没有生成对象)
    params: APIdeleteUserAccountParams,
    options?: RequestConfig
  ) {
    return this.request<number>('/api/LifePay/DeleteUserAccount', {
      method: 'POST',
      params: {
        ...params,
      },
      ...(options || {}),
    });
  }

  /** 获取我的户号详情 GET /api/LifePay/GetUserAccountDetail */
  async getUserAccountDetail(
    // 叠加生成的Param类型 (非body参数swagger默认没有生成对象)
    params: APIgetUserAccountDetailParams,
    options?: RequestConfig
  ) {
    return this.request<UserAccountOutput>('/api/LifePay/GetUserAccountDetail', {
      method: 'GET',
      params: {
        ...params,
      },
      ...(options || {}),
    });
  }

  /** 获取我的订单详情 GET /api/LifePay/GetUserLifePayOrderDetail */
  async getUserLifePayOrderDetail(
    // 叠加生成的Param类型 (非body参数swagger默认没有生成对象)
    params: APIgetUserLifePayOrderDetailParams,
    options?: RequestConfig
  ) {
    return this.request<UserLifePayOrderOutput>('/api/LifePay/GetUserLifePayOrderDetail', {
      method: 'GET',
      params: {
        ...params,
      },
      ...(options || {}),
    });
  }

  /** 搜索管理--列表(区域管理) GET /api/Area/GetRegionalManagementList */
  async getRegionalManagementList(options?: RequestConfig) {
    return this.request<AreaInfo[]>('/api/Area/GetRegionalManagementList', {
      method: 'GET',
      ...(options || {}),
    });
  }

  /** 获取须知 GET /api/LifePay/GetIntroInfo */
  async getIntroInfo(params: APIgetIntroInfoParams, options?: RequestConfig) {
    return this.request<LifePayIntroInfoOutput[]>('/api/LifePay/GetIntroInfo', {
      method: 'GET',
      params: {
        ...params,
      },
      ...(options || {}),
    });
  }

  /** 获取渠道折扣 GET /api/LifePay/GetChannelRate */
  async getChannelRate(body: ChannelsBaseInput, options?: RequestConfig) {
    return this.request<ChannelRateOutput>('/api/LifePay/GetChannelRate', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 获取在线客服 GET /api/LifePay/GetOnlineService */
  async getOnlineService(options?: RequestConfig) {
    return this.request<string>('/api/LifePay/GetOnlineService', {
      method: 'GET',
      ...(options || {}),
    });
  }

  /** 获取全部缴费渠道 GET /api/LifePay/GetLifePayChannlesAllList */
  async getLifePayChannlesAllList(body: QueryLifePayChannlesInput, options?: RequestConfig) {
    return this.request<CreateEditPayChannelsInput[]>('/api/LifePay/GetLifePayChannlesAllList', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 根据用户ID获取用户是否为后台管理员 POST /api/Account/LifePayUserMesssageByIduser */
  async lifePayUserMesssageByIduser(
    body: LifePayUserMesssageByIduserInput,
    options?: RequestConfig
  ) {
    return this.request<LifePayPhoneMesssageCodeLoginOutput>(
      '/api/Account/LifePayUserMesssageByIduser',
      {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        data: body,
        ...(options || {}),
      }
    );
  }

  /** 获取顶部统计数据 GET /api/LifePay/GetTopStatistics */
  async getTopStatistics(
    // 叠加生成的Param类型 (非body参数swagger默认没有生成对象)
    body: TopStatisticsInput,
    options?: RequestConfig
  ) {
    return this.request<TopStatisticsOutput>('/api/LifePay/GetTopStatistics', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 点击数+1 POST /api/Promoter/SetClickCount */
  async setClickCount(
    // 叠加生成的Param类型 (非body参数swagger默认没有生成对象)
    params: APIsetClickCountParams,
    options?: RequestConfig
  ) {
    return this.request<any>('/api/Promoter/SetClickCount', {
      method: 'POST',
      params: {
        ...params,
      },
      ...(options || {}),
    });
  }

  /** 申请渠道咨询 POST /api/Promoter/CreateChannelConsultation */
  async createChannelConsultation(body: CreateChannelConsultationInput, options?: RequestConfig) {
    return this.request<string>('/api/Promoter/CreateChannelConsultation', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }

  /** 创建或更新推广员 POST /api/Promoter/CreateOrUpdatePromoter */
  async createOrUpdatePromoter(body: API.CreateOrUpdatePromoterInput, options?: API.RequestConfig) {
    return this.request<string>('/api/Promoter/CreateOrUpdatePromoter', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      data: body,
      ...(options || {}),
    });
  }
}

export interface PhoneMesssageCodeLoginInput {
  /** 手机号 */
  phoneNumber: string;
  /** 验证码 */
  // code: string;
}

export interface LifePayRateListOutput {
  rateType?: LifeRechargeConstants.LifePayRateTypeEnum;
  rate?: number;
}

export interface ElectricParValueResponse {
  success?: string;
  requestNo?: string;
  partnerId?: string;
  service?: string;
  version?: string;
  protocol?: string;
  context?: string;
  ext?: string;
  code?: string;
  message?: string;
  detail?: string;
  electricParValue?: ElectricParValueOutput[];
}

export interface ElectricParValueOutput {
  electricType?: string;
  areaName?: string;
  parValue?: string;
  rate?: number;
  comments?: string;
}

export interface PhoneParValueResponse {
  success?: boolean;
  requestNo?: string;
  partnerId?: string;
  service?: string;
  version?: string;
  protocol?: string;
  context?: string;
  ext?: any;
  code?: string;
  message?: string;
  detail?: string;
  phoneParValue?: PhoneParValueOutput[];
}

export interface PhoneParValueOutput {
  ispCode?: string;
  ispName?: string;
  parValue?: string[];
  rate?: number;
  phoneSection?: string;
  comments?: string;
}

export interface LifePhoneDataCreateLifePayOrderInput {
  userId?: string;
  /** 渠道Id */
  channelId?: string;
  productData?: LifePhoneData;
}

export interface LifePhoneData {
  /** 运营商编码，例如："yidong", "dianxin", "liantong"。 */
  ispCode: string;
  /** 充值面额，单位为元。测试账户：parValue=100:缴费成功，parValue>100：缴费失败。 */
  parValue: number;
  /** 手机号。 */
  phone: string;
  /** 机主名称(电信手机号必填) */
  name?: string;
}

export interface CreateLifePayOrderOutput {
  orderNo?: string;
}

export interface LifeElectricDataCreateLifePayOrderInput {
  userId?: string;
  /** 渠道Id */
  channelId?: string;
  productData?: LifeElectricData;
}

export interface LifeElectricData {
  /** 充值面额，单位为元。 */
  parValue: number;
  /** 电网类型，例如："guowang"代表国家电网，"nanwang"代表南方电网。 */
  electricType: string;
  /** 电费类型，国网必传：住宅、企事业、店铺三个选项。 */
  electricAccountType: string;
  /** 电费户号。 */
  electricAccount: string;
  /** 省份。 */
  province: string;
  /** 城市。 */
  city: string;
  /** 客户身份证后6位，南网必传。 */
  sixID?: string;
}

export interface APIgetPayStatusByOrderNoParams {
  orderNo?: string;
}

export interface SetLifePayOrderPayTypeInput {
  orderNo: string;
  lifePayType?: LifeRechargeConstants.LifePayTypeEnum;
}

export interface QueryLifePayOrderListInput {
  pageModel?: Pagination;
  lifePayOrderType?: LifeRechargeConstants.LifePayOrderTypeEnum;
  /** 开始支付时间 */
  beginPayTime?: string;
  /** 结束支付时间 */
  endPayTime?: string;
  payStatus?: LifeRechargeConstants.LifePayStatusEnum;
  lifePayOrderStatus?: LifeRechargeConstants.LifePayOrderStatusEnum;
  /** 开始完成时间 */
  beginFinishTime?: string;
  /** 结束完成时间 */
  endFinishTime?: string;
  /** 用户Id */
  userId?: string;
}

export interface Pagination {
  rows?: number;
  page?: number;
  orderInput?: OrderInput[];
  totalCount?: number;
  totalPage?: number;
}

export interface OrderInput {
  property?: string;
  order?: any;
}

export interface UserLifePayOrderOutputPageOutput {
  pageModel?: Pagination;
  objectData?: any;
  data?: UserLifePayOrderOutput[];
}

export interface UserLifePayOrderOutput {
  id?: string;
  lifePayType?: LifeRechargeConstants.LifePayTypeEnum;
  lifePayOrderType?: LifeRechargeConstants.LifePayOrderTypeEnum;
  /** 订单号 */
  orderNo?: string;
  /** 充值金额 */
  rechargeAmount?: number;
  /** 优惠金额 */
  discountAmount?: number;
  /** 实付金额 */
  payAmount?: number;
  /** 支付时间 */
  payTime?: string;
  payStatus?: LifeRechargeConstants.LifePayStatusEnum;
  lifePayOrderStatus?: LifeRechargeConstants.LifePayOrderStatusEnum;
  /** 完成时间 */
  finishTime?: string;
  /** 订单详细数据 */
  orderParamDetailJsonStr?: string;
  /** 下单时间 */
  creationTime?: string;
  /** 退款时间 */
  refundTime?: string;
  /** 退款申请时间 */
  refundApplyTime?: string;
  /** 退款凭证 */
  refundCredentialsImgUrl?: string;
  refundApplyRemark?: string;
  refundCheckRemark?: string;
  /** 渠道流水号 */
  acoolyOrderNo?: string;
  frontStatus?: LifeRechargeConstants.LifePayOrderFrontStatusEnum;
  lifePayRefundStatus?: LifeRechargeConstants.LifePayRefundStatusEnum;
  acoolyStatus?: LifeRechargeConstants.ACOOLYStatusEnum;
}

export interface ElectricSupportAreaResponse {
  success?: boolean;
  requestNo?: string;
  partnerId?: string;
  service?: string;
  version?: string;
  protocol?: string;
  context?: string;
  ext?: any;
  code?: string;
  message?: string;
  detail?: string;
  electricAreaList?: ElectricSupportAreaListOutput[];
}

export interface ElectricSupportAreaListOutput {
  childCityList?: ElectricSupportAreaChildCityListOutput[];
  cityName?: string;
  cityParentId?: string;
  ciytId?: string;
  electricType?: string;
  parValue?: string[];
  rate?: number;
}

export interface ElectricSupportAreaChildCityListOutput {
  cityName?: string;
  cityParentId?: string;
  ciytId?: string;
}
export interface APIgetLifePayWxIndentityParams {
  /** 用户登录凭证 */
  code?: string;
}

export interface WxMiniAppIndentityInfo {
  /** 会话密钥 */
  sessionKey?: string;
  /** 小程序OpenId */
  openId?: string;
  /** 用户名（该值为空则需手机授权登录，不为空则已有该小程序用户） */
  userName?: string;
  unionId?: string;
}

export interface GetPayOrderForJsAPIInput {
  orderNo: string;
  lifePayType?: LifeRechargeConstants.LifePayTypeEnum;
  openId?: string;
  attach?: string;
  payAppId?: string;
}

export interface ModelPaymentMiniPay {
  nonceStr?: string;
  package?: string;
  signType?: string;
  paySign?: string;
  timestamp?: string;
  timeExpire?: string;
  message?: string;
}

export interface QueryUserAccountAllListInput {
  /** 用户Id */
  userId?: string;
  lifePayOrderType?: LifeRechargeConstants.LifePayOrderTypeEnum;
}

export interface UserAccountListOutput {
  id?: string;
  lifePayType?: LifeRechargeConstants.LifePayOrderTypeEnum;
  /** 运营商 */
  operators?: string;
  /** 手机号/户号 */
  content?: string;
  /** 省 */
  province?: string;
  /** 市 */
  city?: string;
  /** 拓展字段（电费类型） */
  extraProperties?: string;
  /** 备注 */
  remark?: string;
  /** 创建时间 */
  creationTime?: string;
  isDeleted?: boolean;
}

export interface AddUpdateUserAccountInput {
  id?: string;
  /** 用户编号 */
  userId?: string;
  lifePayType?: LifeRechargeConstants.LifePayOrderTypeEnum;
  /** 运营商 */
  operators?: string;
  /** 手机号/户号 */
  content?: string;
  /** 省 */
  province?: string;
  /** 市 */
  city?: string;
  /** 拓展字段（电费类型） */
  extraProperties?: string;
  /** 备注 */
  remark?: string;
}

export interface LifeGasDataCreateLifePayOrderInput {
  userId?: string;
  /** 渠道Id */
  channelId?: string;
  productData?: LifeGasData;
}

export interface LifeGasData {
  /** 充值面额，单位为元。 */
  parValue: number;
  /** 天然气公司类型，"zhong_ran"代表中燃燃气，"bei_jing"代表北京燃气。 */
  gasOrgType: string;
  /** 燃气户号 */
  gasAccount: string;
  /** 省份 */
  province: string;
  /** 城市 */
  city?: string;
}

export interface GasParValueResponse {
  success?: boolean;
  requestNo?: string;
  partnerId?: string;
  service?: string;
  version?: string;
  protocol?: string;
  context?: string;
  ext?: any;
  code?: string;
  message?: string;
  detail?: string;
  gasParValue?: GasParValueOutput[];
}

export interface GasParValueOutput {
  gasOrgName?: string;
  gasOrgCode?: string;
  parValue?: string[];
  rate?: number;
  comments?: string;
}

export interface RefundUserLifePayOrderInput {
  id?: string;
  /** 用户Id */
  userId?: string;
  refundApplyRemark?: string;
}

export interface QueryUserAccountListInput {
  pageModel?: Pagination;
  /** 用户Id */
  userId?: string;
  lifePayOrderType?: LifeRechargeConstants.LifePayOrderTypeEnum;
}

export interface UserAccountListOutputPageOutput {
  pageModel?: Pagination;
  objectData?: any;
  data?: UserAccountListOutput[];
}

export interface APIdeleteUserAccountParams {
  id?: string;
}

export interface APIgetUserAccountDetailParams {
  id?: string;
}

export interface UserAccountOutput {
  id?: string;
  lifePayType?: LifeRechargeConstants.LifePayOrderTypeEnum;
  /** 运营商 */
  operators?: string;
  /** 手机号/户号 */
  content?: string;
  /** 省 */
  province?: string;
  /** 市 */
  city?: string;
  /** 拓展字段（电费类型） */
  extraProperties?: string;
  /** 备注 */
  remark?: string;
  /** 创建时间 */
  creationTime?: string;
  isDeleted?: boolean;
}

export interface APIgetUserLifePayOrderDetailParams {
  orderNo?: string;
}

export interface ChannelsBaseInput {
  checkChannelId?: string;
}

export interface AreaInfo {
  areaCode?: number;
  parentId?: number;
  areaName?: string;
  /** 1省 2市 3区 4镇 */
  layer?: number;
  sort?: number;
  children?: AreaInfo[];
  /** 简易拼音 */
  simpleSpelling?: string;
  /** 快速检索 */
  quickQuery?: string;
}

export interface GetPayStatusByOrderNoInput {
  checkChannelId?: string;
  orderNo?: string;
}

export interface APIgetIntroInfoParams {
  type?: LifeRechargeConstants.LifePayOrderTypeEnum;
}

export interface LifePayIntroInfoOutput {
  type?: IntroInfoTypeEnum;
  lifePayType?: LifeRechargeConstants.LifePayOrderTypeEnum;
  /** 摘要 */
  contentSummary?: string;
  /** 文本内容 */
  content?: string;
  /** 图片/视频路径 */
  path?: string;
  /** 排序 */
  sequence?: number;
}

export type IntroInfoTypeEnum = 0 | 1 | 2 | 3 | 4;

export interface ChannelRateOutput {
  channlesRate?: number;
}

export interface CreateEditPayChannelsInput {
  id?: string;
  channlesName?: string;
  channlesNum?: string;
  channlesRate?: number;
  channlesRakeRate?: number;
}

export interface LifePayPhoneMesssageCodeLoginOutput {
  /** 用户Id */
  userId?: string;
  /** 是否是后台用户 */
  isBackClientUser?: boolean;
  /** 渠道号 */
  channlesNum?: ChannelOutput[];
}

export interface ChannelOutput {
  name?: string;
  channlesNum?: string;
  channlesId?: string;
  switchType?: LifeRechargeConstants.LifePaySwitchTypeEnum;
}

export interface LifePayUserMesssageByIduserInput {
  pageModel?: Pagination;
  checkChannelId?: string;
  /** 用户编号 */
  id?: string;
}

export interface TopStatisticsInput {
  channleList?: string[];
}

export interface TopStatisticsOutput {
  /** 创建时间 */
  creationTime?: string;
  /** 账户余额 */
  amount?: number;
  /** 累计收款 */
  accumulatedReceipts?: number;
  /** 昨日收款 */
  receiptsYesterday?: number;
  /** 累计收入 */
  accumulatedIncome?: number;
  /** 累计下单 */
  accumulatedOrders?: number;
  /** 昨日下单 */
  ordersNumYesterday?: number;
  /** 昨日成功 */
  yesterdaySuccess?: number;
  /** 昨日失败 */
  yesterdayFail?: number;
  /** 累计用户 */
  accumulatedUsers?: number;
  /** 昨日活跃用户 */
  yesterdayActiveUsers?: number;
}

export interface QueryLifePayChannlesInput {
  status?: LifeRechargeConstants.LifePayChannelsStatsEnum;
}

export interface APIsetClickCountParams {
  idnumber?: string;
}

export interface CreateChannelConsultationInput {
  /** 客户端用户Id 如有 */
  userId?: string;
  /** 推广人Id */
  idNumber?: string;
  /** 咨询人 */
  name?: string;
  agentType?: LifeRechargeConstants.LifePayChannelAgentType;
  /** 联系方式 */
  phoneNumber?: string;
  /** 公司名称 */
  companyName?: string;
  /** 客户资源 */
  customerResources?: string;
}

export interface CreateOrUpdatePromoterInput {
  /** Id */
  id?: string;
  /** 客户端用户Id 如有 */
  userId?: string;
  /** ID */
  idNumber?: string;
  /** 推广员 */
  name?: string;
  /** 联系方式 */
  phoneNumber?: string;
  /** 备注 */
  remark?: string;
}
